@@ -413,7 +413,8 @@ class QuoteData(object):
         return df
 
     @assert_quote_init
-    def execute_technical_analysis(self, data, indications, inplace=False, skip_sort=False) -> pd.DataFrame:
+    def execute_technical_analysis(self, data, indications, prefix=None
+                                   , lowercase=True, inplace=False, skip_sort=False) -> pd.DataFrame:
         """执行技术指标运算
 
         参数:
@@ -422,6 +423,8 @@ class QuoteData(object):
                          单个指标：（'MA', 5)，
                          多个指标：[('MA', 5), ('KDJ', 9, 3, 3)]
                          可省略参数：['MA', 'KDJ']
+            prefix: 指标名称前缀，默认值 None
+            lowercase: 指标名称是否小写，默认值 True
             inplace: 是否复盖输入数据，默认值 False
             skip_sort: 跳过排序，默认值 False；传入的 data 必须符合 code, datetime 排序，否则处理结果会有误
 
@@ -448,8 +451,8 @@ class QuoteData(object):
             if not hasattr(func, '__wrapped__'):
                 print('%s is unavailable.' % c)
                 continue
-            f_code = getattr(func, '__wrapped__').__code__
-            f_args = [x for x in f_code.co_varnames[:f_code.co_argcount]]
+            f_wrapped = getattr(func, '__wrapped__')
+            f_args = [x for x in f_wrapped.__code__.co_varnames[:f_wrapped.__code__.co_argcount]]
             if len(f_args) > 0 and f_args[0] == 'X' and len(v) > 0 and type(v[0]) is not str:
                 f_args.pop(0)
             kw = dict(axis=1)
@@ -459,32 +462,48 @@ class QuoteData(object):
                 kw[f_args[i]] = v[i]
 
             # 获取返回值字段名
-            cols_fn = arithmetic_returns(f_code)
+            cols_fn = arithmetic_returns(f_wrapped, v)
             if not cols_fn:
                 cols_fn = c
             if type(cols_fn) is str:
                 cols_fn = [cols_fn]
-            cols_fn = [x.lower() for x in cols_fn]
+            cols_fn = [x for x in cols_fn]
             if not cols_fn:
                 raise Exception('columns name not support.')
 
             # 字段重名处理
+            cols_nums = dict()
+            for x in cols_techansi:
+                arr = x.split('_')
+                if len(arr) > 1 and arr[-1].isdigit():
+                    y = int(arr[-1])
+                    x = '_'.join(arr[:-1])
+                    if y >= cols_nums[x]:
+                        cols_nums[x] = y + 1
+                else:
+                    cols_nums[x] = 1
+            for i in range(len(cols_fn)):
+                x = cols_fn[i]
+                if x in cols_nums.keys():
+                    cols_fn[i] = x + '_' + str(cols_nums[x])
+            '''
             if [x for x in cols_fn if x in cols_techansi]:
-                c_arr = [str(x).lower() for x in v]
+                c_arr = [str(x) for x in v]
                 if len(cols_fn) > 1:
-                    c_arr.insert(0, c.lower())
+                    c_arr.insert(0, c)
                     cols_fn = ['_'.join(c_arr) + '_' + x for x in cols_fn]
                 elif len(cols_fn) == 1:
-                    if cols_fn[0] == c.lower():
-                        c_arr.insert(0, c.lower())
+                    if cols_fn[0] == c:
+                        c_arr.insert(0, c)
                         cols_fn = ['_'.join(c_arr)]
                     else:
                         c_arr.insert(0, cols_fn[0])
                         cols_fn = ['_'.join(c_arr)]
+            '''
 
             # 加入操作参数
             operate_params.append((cols_fn, func, kw))
-            cols_techansi.extend(cols_fn)
+            cols_techansi.extend([x for x in cols_fn if x not in cols_techansi])
 
         # 提交指标函数处理
         multi_process = self._options.get('multi_process', False)
@@ -515,6 +534,19 @@ class QuoteData(object):
                 if not se.empty:
                     df.loc[se.index, cols_fn] = se.tolist() if len(cols_fn) > 1 else se
 
+        #指标名称-变更前缀或转换大小写
+        cols_maps = dict()
+        for x in df.columns:
+            if x not in cols_techansi:
+                continue
+            y = x
+            y = y.lower() if lowercase else y.upper()
+            if prefix:
+                y = prefix + y
+            if x != y:
+                cols_maps[x] = y
+        df.rename(columns=cols_maps, inplace=True)
+
         # self.trace('exec', time.time() - proc_start)
         return df
 
