@@ -13,15 +13,13 @@ def VR(N=26, M=6):
         TQ:=SUM(IF(CLOSE=REF(CLOSE,1),VOL,0),N);
         VR:100*(TH*2+TQ)/(TL*2+TQ);
         MAVR:MA(VR,M);
-        TH赋值:如果收盘价>1日前的收盘价,返回成交量(手),否则返回0的N日累和
-        TL赋值:如果收盘价<1日前的收盘价,返回成交量(手),否则返回0的N日累和
-        TQ赋值:如果收盘价=1日前的收盘价,返回成交量(手),否则返回0的N日累和
-        输出VR:100*(TH*2+TQ)/(TL*2+TQ)
-        输出MAVR:VR的M日简单移动平均
     输入：
-        N：统计的天数 N
-        M：统计的天数 M
+        N：统计周期数 N
+        M：统计周期数 M
     输出：
+        VR: 成交量变动率
+        MAVR：成交量变动率的M周期平均
+    定义：
         RETURNS=(VR, MAVR)
 
     """
@@ -30,4 +28,23 @@ def VR(N=26, M=6):
     TQ = SUM(IF(CLOSE == REF(CLOSE, 1), VOL, 0), N)
     VR = 100 * (TH * 2 + TQ) / (TL * 2 + TQ)
     MAVR = MA(VR, M)
-    return VR, MAVR
\ No newline at end of file
+    return VR, MAVR
+
+
+@arithmetic_wrapper
+def PSY(N=12, M=6):
+    """
+    公式：
+        PSY:COUNT(CLOSE>REF(CLOSE,1),N)/N*100;
+        MAPSY:MA(PSY,M);
+    输入：
+        N：统计的天数 N
+    输出：
+        PSY: N周期的PSY值
+        MAPSY: PSY的M周期移动平均
+    定义：
+        RETURNS=(PSY, MAPSY)
+    """
+    PSY = COUNT(CLOSE > REF(CLOSE, 1), N) / N * 100
+    MAPSY = MA(PSY, M)
+    return PSY, MAPSY
\ No newline at end of file
